package java.awt.dnd;

import java.awt.datatransfer.Transferable;
import java.util.List;
import java.awt.datatransfer.DataFlavor;
import java.awt.Point;

public class DropTargetDropEvent extends DropTargetEvent
{
    private static final long serialVersionUID = -1721911170440459322L;
    private static final Point zero;
    private Point location;
    private int actions;
    private int dropAction;
    private boolean isLocalTx;
    
    public DropTargetDropEvent(DropTargetContext dropTargetContext, Point location, int n, int actions) {
        super(dropTargetContext);
        this.location = DropTargetDropEvent.zero;
        this.actions = 0;
        this.dropAction = 0;
        this.isLocalTx = false;
        if (location == null) {
            throw new NullPointerException("cursorLocn");
        }
        if (n != 0 && n != 1 && n != 2 && n != 1073741824) {
            throw new IllegalArgumentException("dropAction = " + n);
        }
        if ((actions & 0xBFFFFFFC) != 0x0) {
            throw new IllegalArgumentException("srcActions");
        }
        this.location = location;
        this.actions = actions;
        this.dropAction = n;
        return;
    }
    
    public DropTargetDropEvent(DropTargetContext dropTargetContext, Point point, int n, int n2, boolean isLocalTx) {
        this(dropTargetContext, point, n, n2);
        this.isLocalTx = isLocalTx;
    }
    
    public Point getLocation() {
        return this.location;
    }
    
    public DataFlavor[] getCurrentDataFlavors() {
        return this.getDropTargetContext().getCurrentDataFlavors();
    }
    
    public List<DataFlavor> getCurrentDataFlavorsAsList() {
        return this.getDropTargetContext().getCurrentDataFlavorsAsList();
    }
    
    public boolean isDataFlavorSupported(DataFlavor dataFlavor) {
        return this.getDropTargetContext().isDataFlavorSupported(dataFlavor);
    }
    
    public int getSourceActions() {
        return this.actions;
    }
    
    public int getDropAction() {
        return this.dropAction;
    }
    
    public Transferable getTransferable() {
        return this.getDropTargetContext().getTransferable();
    }
    
    public void acceptDrop(int n) {
        this.getDropTargetContext().acceptDrop(n);
    }
    
    public void rejectDrop() {
        this.getDropTargetContext().rejectDrop();
    }
    
    public void dropComplete(boolean b) {
        this.getDropTargetContext().dropComplete(b);
    }
    
    public boolean isLocalTransfer() {
        return this.isLocalTx;
    }
    
    static {
        zero = new Point(0, 0);
    }
}
